@@ -1222,52 +1222,52 @@ unsigned int TXT_Font[][11]= {
    0x0000,  // ************ ****
    0x0000   // ************ ****
   },
-  { // 0x84 = 
-   0x0600,  // *****##***** ****
-   0x3FC0,  // **########** ****
-   0x6660,  // *##**##**##* ****
-   0x6600,  // *##**##***** ****
-   0x3FC0,  // **########** ****
-   0x0660,  // *****##**##* ****
-   0x6660,  // *##**##**##* ****
-   0x3FC0,  // **########** ****
-   0x0600,  // *****##***** ****
+  { // 0x84 =
+   0x0700,  // *****###**** ****
+   0x0D80,  // ****##*##*** ****
+   0x0700,  // *****###**** ****
+   0x3060,  // **##*****##* ****
+   0x3060,  // **##*****##* ****
+   0x3060,  // **##*****##* ****
+   0x30E0,  // **##****###* ****
+   0x1F60,  // ***#####*##* ****
+   0x0000,  // ************ ****
    0x0000   // ************ ****
   },
-  { // 0x85 = 
-   0x07F0,  // *****####### ****
-   0x0C00,  // ****##****** ****
-   0x19F0,  // ***##**##### ****
+  { // 0x85 =
+   0x06C0,  // *****##*##** ****
+   0x0380,  // ******###*** ****
+   0x0000,  // ************ ****
+   0x0FE0,  // ****#######* ****
    0x1800,  // ***##******* ****
-   0x19F0,  // ***##**##### ****
+   0x3000,  // **##******** ****
    0x1800,  // ***##******* ****
-   0x19F0,  // ***##**##### ****
-   0x0C00,  // ****##****** ****
-   0x07F0,  // *****####### ****
+   0x0FE0,  // ****#######* ****
+   0x0000,  // ************ ****
    0x0000   // ************ ****
   },
-  { // 0x86 = 
-   0xFFC0,  // ##########** ****
-   0x1C60,  // ***###***##* ****
-   0x0830,  // ****#*****## ****
-   0x7F30,  // *#######**## ****
-   0x4130,  // *#*****#**## ****
-   0x7F30,  // *#######**## ****
-   0x0830,  // ****#*****## ****
-   0x1C60,  // ***###***##* ****
-   0xFFC0,  // ##########** ****
+  { // 0x86 =
+   0x0D80,  // ****##*##*** ****
+   0x0700,  // *****###**** ****
+   0x0000,  // ************ ****
+   0x1FC0,  // ***#######** ****
+   0x3000,  // **##******** ****
+   0x1FC0,  // ***#######** ****
+   0x0060,  // *********##* ****
+   0x1FC0,  // ***#######** ****
+   0x0000,  // ************ ****
    0x0000   // ************ ****
   },
-  { // 0x87 = 
-   0xFFC0,  // ##########** ****
-   0x0060,  // *********##* ****
-   0x3E30,  // **#####***## ****
-   0x6330,  // *##***##**## ****
-   0x0E30,  // ****###***## ****
-   0x1830,  // ***##*****## ****
-   0x1830,  // ***##*****## ****
-   0x0060,  // *********##* ****
-   0xFFC0,  // ##########** ****
+  { // 0x87 =
+   0x0D80,  // ****##*##*** ****
+   0x0700,  // *****###**** ****
+   0x0000,  // ************ ****
+   0x33E0,  // **##**#####* ****
+   0x3C00,  // **####****** ****
+   0x3000,  // **##******** ****
+   0x3000,  // **##******** ****
+   0x3000,  // **##******** ****
+   0x0000,  // ************ ****
    0x0000   // ************ ****
   },
   { // 0x88 = 
@@ -1354,19 +1354,18 @@ unsigned int TXT_Font[][11]= {
    0x0600,  // *****##***** ****
    0x0600   // *****##***** ****
   },
-  { // 0x8F = 
+  { // 0x8F =
+   0x0D80,  // ****##*##*** ****
+   0x0700,  // *****###**** ****
+   0x0000,  // ************ ****
+   0x1FC0,  // ***#######** ****
+   0x3060,  // **##*****##* ****
+   0x3FE0,  // **#########* ****
+   0x3000,  // **##******** ****
+   0x1FC0,  // ***#######** ****
    0x0000,  // ************ ****
-   0x1980,  // ***##**##*** ****
-   0x1980,  // ***##**##*** ****
-   0x7FE0,  // *##########* ****
-   0x1980,  // ***##**##*** ****
-   0x1980,  // ***##**##*** ****
-   0x7FE0,  // *##########* ****
-   0x1980,  // ***##**##*** ****
-   0x1980,  // ***##**##*** ****
    0x0000   // ************ ****
   },
-
   { // 0x90 = 
    0x0300,  // ******##**** ****
    0x0600,  // *****##***** ****
@@ -1391,30 +1390,30 @@ unsigned int TXT_Font[][11]= {
    0x0000,  // ************ ****
    0x0000   // ************ ****
   },
-  { // 0x92 = 
+  { // 0x92 =
+   0x0300,  // ******##**** ****
+   0x0600,  // *****##***** ****
    0x0000,  // ************ ****
-   0x3180,  // **##***##*** ****
+   0x3060,  // **##*****##* ****
+   0x18C0,  // ***##***##** ****
+   0x0D80,  // ****##*##*** ****
+   0x0700,  // *****###**** ****
+   0x0600,  // *****##***** ****
+   0x0C00,  // ****##****** ****
+   0x3800   // **###******* ****
+  },
+  { // 0x93 =
+   0x0D80,  // ****##*##*** ****
+   0x0700,  // *****###**** ****
    0x0000,  // ************ ****
-   0x7F80,  // *########*** ****
-   0x00C0,  // ********##** ****
-   0x3FC0,  // **########** ****
-   0x60C0,  // *##*****##** ****
+   0x3FE0,  // **#########* ****
+   0x0180,  // *******##*** ****
+   0x0700,  // *****###**** ****
+   0x0C00,  // ****##****** ****
    0x3FE0,  // **#########* ****
    0x0000,  // ************ ****
    0x0000   // ************ ****
-  },
-  { // 0x93 = 
-   0x0000,  // ************ ****
-   0x1980,  // ***##**##*** ****
-   0x1980,  // ***##**##*** ****
-   0x7FE0,  // *##########* ****
-   0x1980,  // ***##**##*** ****
-   0x1980,  // ***##**##*** ****
-   0x7FE0,  // *##########* ****
-   0x1980,  // ***##**##*** ****
-   0x1980,  // ***##**##*** ****
-   0x0000   // ************ ****
-  },
+   },
   { // 0x94 = 
    0x0000,  // ************ ****
    0x6060,  // *##******##* ****
@@ -1427,16 +1426,16 @@ unsigned int TXT_Font[][11]= {
    0x6060,  // *##******##* ****
    0x0000   // ************ ****
   },
-  { // 0x95 = 
-   0xFFC0,  // ##########** ****
-   0x0060,  // *********##* ****
-   0xFF30,  // ########**## ****
-   0x0030,  // **********## ****
-   0xFF30,  // ########**## ****
-   0x0030,  // **********## ****
-   0xFF30,  // ########**## ****
-   0x0060,  // *********##* ****
-   0xFFC0,  // ##########** ****
+  { // 0x95 =
+   0x001B,  // *******##*## ****
+   0x0C0E,  // ****##**###* ****
+   0x0C00,  // ****##****** ****
+   0x3F80,  // **#######*** ****
+   0x0C00,  // ****##****** ****
+   0x0C00,  // ****##****** ****
+   0x0C00,  // ****##****** ****
+   0x07E0,  // *****######* ****
+   0x0000,  // ************ ****
    0x0000   // ************ ****
   },
   { // 0x96 = 
@@ -3112,7 +3111,7 @@ int NationalOptionSubsetG0Default[13]=
     {0x23,0x94,0x80,0   ,0   ,0   ,0x5e,0x5f,0   ,0   ,0   ,0   ,0   };
 
 int NationalOptionSubsetCZ_SK[13]=
-    {0x23,0   ,0   ,0   ,0   ,0   ,0xed,0   ,0xec,0xeb,0   ,0xef,0   };
+    {0x23,0x84,0x85,0x95,0x93,0x92,0xed,0x87,0x91,0xeb,0x8f,0xef,0x86};
 int NationalOptionSubsetEN[13]=
     {0x83,0x24,0x80,0x8b,0x8c,0x8d,0x8e,0x23,0x81,0x82,0x88,0x89,0x8a};
 int NationalOptionSubsetEE[13]=
@@ -3260,6 +3259,16 @@ unsigned int* GetFontChar(cTeletextChar c, unsigned int *buffer) {
         }
         break;
     case CHARSET_LATIN_G0_CZ_SK:
+        if (NationalOption>=0) {
+            if (NationalOptionSubsetCZ_SK[NationalOption]>0)
+                bitmap=TXT_Font[NationalOptionSubsetCZ_SK[NationalOption]-0x20];
+        } else {
+            if (chr>=0x20 && chr<0x80) {
+                bitmap=TXT_Font[chr-0x20];
+	    }
+        }
+        break;
+
     case CHARSET_LATIN_G0_EE:
     case CHARSET_LATIN_G0_LV_LT:
     case CHARSET_LATIN_G0_PL:
